Factory Djoy
::::::::::::

.. image:: https://circleci.com/gh/jamescooke/factory_djoy.svg?style=shield
    :target: https://circleci.com/gh/jamescooke/factory_djoy
.. image:: https://img.shields.io/pypi/pyversions/factory_djoy.svg?maxAge=2592000
    :target: https://pypi.python.org/pypi/factory_djoy
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://raw.githubusercontent.com/jamescooke/factory_djoy/master/LICENSE

Simple wrappers around Factory Boy for Django which call ``full_clean`` when
creating instances to ensure that only valid data enters your Django database.

Compatible with:

* Latest flavours of Django 1.8, 1.9 and 1.10.

* Python 2.7, 3.4 and 3.5.

* Factory Boy version 2 or greater.


Resources
=========

* `Documentation on ReadTheDocs <https://factory-djoy.readthedocs.io/>`_

* `Package on PyPI <https://pypi.python.org/pypi/factory_djoy>`_

* `Source code on GitHub <https://github.com/jamescooke/factory_djoy>`_

* `Licensed on MIT <https://raw.githubusercontent.com/jamescooke/factory_djoy/master/LICENSE>`_
